@@ -23,6 +23,7 @@ from ldeep.views.cache_activedirectory import CacheActiveDirectoryView
 
 from ldeep.utils import error, info, Logger, resolve as utils_resolve
 from ldeep.utils.structure import Structure
+from ldeep.utils.sddl import parse_ntSecurityDescriptor
 
 import sys
 
@@ -59,6 +60,8 @@ class Ldeep(Command):
 					print(record["dn"])
 				elif "pKIEnrollmentService" in record["objectClass"]:
 					print(record["dNSHostName"])
+				elif "msDS-AuthNPolicy" in record["objectClass"] or "msDS-AuthNPolicySilo" in record["objectClass"]:
+					print(record["cn"])
 
 	def __display_json(self, records, default):
 		json_dump(records, sys.stdout, ensure_ascii=False, default=default, sort_keys=True, indent=2)
@@ -485,6 +488,140 @@ class Ldeep(Command):
 				output += " | Subnet description: {}".format(subnet_description) if subnet_description else ""
 				print(output)
 
+	def list_conf(self, kwargs):
+		"""
+		Dump the configuration partition of the Active Directory.
+		"""
+		self.display(
+			self.engine.query(
+				self.engine.ALL_FILTER(),
+				ALL, base=','.join(["CN=Configuration", self.engine.base_dn])
+			),
+			True
+		)
+
+	def list_auth_policies(self, kwargs):
+		"""
+		List the authentication policies configured in the Active Directory.
+
+		Arguments:
+			@verbose:bool
+				Results will contain full information
+		"""
+		verbose = kwargs.get("verbose", False)
+		attributes = ALL if verbose else ["cn", "objectClass"]
+
+		self.display(
+			self.engine.query(
+				self.engine.AUTH_POLICIES_FILTER(),
+				attributes, base=','.join(["CN=AuthN Policy Configuration,CN=Services,CN=Configuration", self.engine.base_dn])
+			),
+			verbose
+		)
+
+	def list_silos(self, kwargs):
+		"""
+		List the silos configured in the Active Directory.
+
+		Arguments:
+			@verbose:bool
+				Results will contain full information
+		"""
+		verbose = kwargs.get("verbose", False)
+		attributes = ALL if verbose else ["cn", "objectClass"]
+
+		self.display(
+			self.engine.query(
+				self.engine.SILOS_FILTER(),
+				attributes, base=','.join(["CN=AuthN Policy Configuration,CN=Services,CN=Configuration", self.engine.base_dn])
+			),
+			verbose
+		)
+
+	def list_smsa(self, kwargs):
+		"""
+		List the smsa accounts and the machines they are associated with.
+
+		Arguments:
+			@verbose:bool
+				Results will contain full information
+		"""
+
+		verbose = kwargs.get("verbose", False)
+		attributes = ALL if verbose else ["samAccountName", "msDS-HostServiceAccountBL"]
+		entries = self.engine.query(self.engine.SMSA_FILTER(), attributes)
+
+		if verbose:
+			self.display(entries, verbose)
+		else:
+			for entry in entries:
+				sam = entry['sAMAccountName']
+				for host in entry["msDS-HostServiceAccountBL"]:
+					print(f'{sam}:{host}')
+
+	def list_delegations(self, kwargs):
+		"""
+		List accounts configured for any kind of delegation.
+
+		Arguments:
+			@verbose:bool
+				Results will contain full information
+			@filter:string = ["all", "unconstrained", "constrained", "rbcd"]
+		"""
+		verbose	 = kwargs.get("verbose", False)
+		filter_	 = kwargs.get("filter", "all")
+
+		attributes = ALL if verbose else ["samAccountName", "userAccountControl"]
+
+		if filter_ == "all":
+			if not verbose:
+				attributes.extend([
+					"msDS-AllowedToDelegateTo",
+					"msDS-AllowedToActOnBehalfOfOtherIdentity"
+				])
+			entries = self.engine.query(self.engine.ALL_DELEGATIONS_FILTER(), attributes)
+		elif filter_ == "unconstrained":
+			entries = self.engine.query(self.engine.UNCONSTRAINED_DELEGATION_FILTER(), attributes)
+		elif filter_ == "constrained":
+			if not verbose:
+				attributes.append("msDS-AllowedToDelegateTo")
+			entries = self.engine.query(self.engine.CONSTRAINED_DELEGATION_FILTER(), attributes)
+		elif filter_ == "rbcd":
+			if not verbose:
+				attributes.append("msDS-AllowedToActOnBehalfOfOtherIdentity")
+			entries = self.engine.query(self.engine.RESOURCE_BASED_CONSTRAINED_DELEGATION_FILTER(), attributes)
+		else:
+			return None
+
+		if verbose:
+			self.display(entries, verbose)
+		else:
+			for entry in entries:
+				try:
+					uac = entry["userAccountControl"]
+					sam = entry["samAccountName"]
+					delegate = entry.get("msDS-AllowedToDelegateTo")
+					allowed_to_act = entry.get("msDS-AllowedToActOnBehalfOfOtherIdentity")
+					if (filter_ == "unconstrained" or filter_ == "all") and "TRUSTED_FOR_DELEGATION" in uac:
+						print(f"{sam}:unconstrained:")
+					if (filter_ == "constrained" or filter_ == "all") and delegate:
+						transition = "with" if "TRUSTED_TO_AUTH_FOR_DELEGATION" in uac else "without"
+						for a in delegate:
+							print(f"{sam}:constrained {transition} protocol transition:{a}")
+					if (filter_ == "rbcd" or filter_ == "all") and allowed_to_act:
+						sd = parse_ntSecurityDescriptor(allowed_to_act)
+						for ace in sd['DACL']['ACEs']:
+							try:
+								sid = ace.get('SID')
+								if not sid:
+									continue
+								res = self.engine.resolve_sid(sid)
+								name = res[0]['samAccountName']
+								print(f"{name}:rbcd:{sam}")
+							except Exception:
+								print(f"{sid}:rbcd:{sam}")
+				except Exception:
+					continue
 
 	# GETTERS #
 
@@ -653,6 +790,46 @@ class Ldeep(Command):
 
 		self.display(results, True, False)
 
+	def get_silo(self, kwargs):
+		"""
+		Get information about a specific `silo`.
+
+		Arguments:
+			#silo:string
+				Silo to query
+			@information:string = ["all", "members", "auth_policies"]
+				Information to query
+		"""
+		silo = kwargs["silo"]
+		info = kwargs["information"]
+
+		if info == "all":
+			attributes = ALL
+		elif info == "members":
+			attributes = ["msDS-AuthNPolicySiloMembers"]
+		elif info == "auth_policies":
+			attributes = ["msDS-ComputerAuthNPolicy", "msDS-ServiceAuthNPolicy", "msDS-UserAuthNPolicy"]
+		else:
+			return None
+
+		results = self.engine.query(
+			self.engine.SILO_FILTER(silo),
+			attributes,
+			base=','.join(["CN=AuthN Policy Configuration,CN=Services,CN=Configuration", self.engine.base_dn])
+		)
+		if not results:
+			error(f"Silo {silo} does not exists")
+
+		if info == "all":
+			self.display(results, True)
+		elif info == "members":
+			members = results[0]["msDS-AuthNPolicySiloMembers"]
+			print(*members, sep="\n")
+		elif info == "auth_policies":
+			print(f"msDS-ComputerAuthNPolicy: {results[0]['msDS-ComputerAuthNPolicy']}")
+			print(f"msDS-ServiceAuthNPolicy: {results[0]['msDS-ServiceAuthNPolicy']}")
+			print(f"msDS-UserAuthNPolicy: {results[0]['msDS-UserAuthNPolicy']}")
+
 	# MISC #
 
 	def misc_search(self, kwargs):
