@@ -159,7 +159,16 @@ class LdapActiveDirectoryView(ActiveDirectoryView):
 	TRUSTS_INFO_FILTER = lambda _: "(objectCategory=trustedDomain)"
 	OU_FILTER = lambda _: "(|(objectClass=OrganizationalUnit)(objectClass=domain))"
 	ENUM_USER_FILTER = lambda _, n: f"(&(NtVer=\x06\x00\x00\x00)(AAC=\x10\x00\x00\x00)(User={n}))"
-
+	ALL_FILTER = lambda _: "(objectClass=*)"
+	AUTH_POLICIES_FILTER = lambda _: "(objectClass=msDS-AuthNPolicy)"
+	SILOS_FILTER = lambda _: "(objectClass=msDS-AuthNPolicySilo)"
+	SILO_FILTER = lambda _, s: f"(&(objectClass=msDS-AuthNPolicySilo)(cn={s}))"
+	SMSA_FILTER = lambda _: "(ObjectClass=msDS-ManagedServiceAccount)"
+	UNCONSTRAINED_DELEGATION_FILTER = lambda _: f"(userAccountControl:1.2.840.113556.1.4.803:=524288)"
+	CONSTRAINED_DELEGATION_FILTER = lambda _: f"(msDS-AllowedToDelegateTo=*)"
+	RESOURCE_BASED_CONSTRAINED_DELEGATION_FILTER = lambda _: f"(msDS-AllowedToActOnBehalfOfOtherIdentity=*)"
+	ALL_DELEGATIONS_FILTER = lambda _: f"(|(userAccountControl:1.2.840.113556.1.4.803:=524288)(msDS-AllowedToDelegateTo=*)(msDS-AllowedToActOnBehalfOfOtherIdentity=*))"
+	
 	class ActiveDirectoryLdapException(Exception):
 		pass
 
